@@ -39,9 +39,9 @@ namespace BluezQt
 ManagerPrivate::ManagerPrivate(Manager *parent)
     : QObject(parent)
     , q(parent)
-    , m_dbusObjectManager(0)
-    , m_bluezAgentManager(0)
-    , m_bluezProfileManager(0)
+    , m_dbusObjectManager(nullptr)
+    , m_bluezAgentManager(nullptr)
+    , m_bluezProfileManager(nullptr)
     , m_usableAdapter(0)
     , m_initialized(false)
     , m_bluezRunning(false)
@@ -206,12 +206,12 @@ void ManagerPrivate::clear()
 
     if (m_dbusObjectManager) {
         m_dbusObjectManager->deleteLater();
-        m_dbusObjectManager = Q_NULLPTR;
+        m_dbusObjectManager = nullptr;
     }
 
     if (m_bluezAgentManager) {
         m_bluezAgentManager->deleteLater();
-        m_bluezAgentManager = Q_NULLPTR;
+        m_bluezAgentManager = nullptr;
     }
 }
 
@@ -353,7 +353,10 @@ void ManagerPrivate::addAdapter(const QString &adapterPath, const QVariantMap &p
 void ManagerPrivate::addDevice(const QString &devicePath, const QVariantMap &properties)
 {
     AdapterPtr adapter = m_adapters.value(properties.value(QStringLiteral("Adapter")).value<QDBusObjectPath>().path());
-    Q_ASSERT(adapter);
+    if (!adapter) {
+        return;
+    }
+
     DevicePtr device = DevicePtr(new Device(devicePath, properties, adapter));
     device->d->q = device.toWeakRef();
     m_devices.insert(devicePath, device);
